<html>
<title><?cs var:html_escape(BBS_TITLE) ?></title>
<meta http-equiv="Content-Type" content="text/html;charset=sjis">
<body>
<?cs if:Banner ?><?cs var:Banner ?><hr><?cs /if ?>
<a name=u></a>
<form action=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/i><input name=s size=11>
<input type=submit value=>
<a href=#b accesskey=8></a>
</form>
<?cs var:html_escape(Title) ?><hr>
<?cs each:item = Threads ?>
<?cs var:html_escape(item.index) ?>:<a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/i>
<?cs var:item.subject ?>  (<?cs var:html_escape(item.res) ?>)</a><br>
<?cs /each ?>
<hr>
<a name=b></a>
<a href=#u accesskey=2></a>
<?cs if:Count ?>
<a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(Next) ?> accesskey=9></a>
<?cs /if ?>
<?cs if:Count ?>
<a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/101 accesskey=1>101-</a>
<?cs /if ?>
<a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/w accesskey=4></a>
<a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/c accesskey=5></a>
<a href=<?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/. accesskey=6></a>
<a href=<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?m=1></a>
<?cs if:BBS_ACCEPT_MAILPOST ?>
<a href=<?cs var:html_escape(CGIURI) ?>/m.cgi/<?cs var:html_escape(BBS) ?>/>X</a>
<?cs /if ?>
</body>
</html>
